Program Stages
**************

.. currentmodule:: ModernGL

.. autoclass:: ProgramStage
	:members: subroutines, subroutine_uniforms

.. toctree::
	:maxdepth: 4

	Subroutines <Subroutines.rst>
	SubroutineUniforms <SubroutineUniforms.rst>
